@@ -8,6 +8,8 @@ use crate::operator::ArithmeticOperator;
 use crate::operator::BinaryBitwiseOperator;
 use crate::operator::BinaryLogicalOperator;
 use crate::operator::ComparisonOperator;
+use crate::operator::ContainsOperator;
+use crate::operator::OverlapOperator;
 use crate::operator::PrefixUnaryOperator;
 
 #[derive(PartialEq)]
@@ -25,6 +27,7 @@ pub enum ExpressionKind {
     Arithmetic,
     Comparison,
     Contains,
+    Overlap,
     Like,
     Regex,
     Glob,
@@ -218,7 +221,7 @@ impl Expression for BooleanExpression {
 
 pub struct UnaryExpression {
     pub right: Box<dyn Expression>,
-    pub op: PrefixUnaryOperator,
+    pub operator: PrefixUnaryOperator,
 }
 
 impl Expression for UnaryExpression {
@@ -227,7 +230,7 @@ impl Expression for UnaryExpression {
     }
 
     fn expr_type(&self, scope: &Environment) -> DataType {
-        if self.op == PrefixUnaryOperator::Bang {
+        if self.operator == PrefixUnaryOperator::Bang {
             DataType::Boolean
         } else {
             self.right.expr_type(scope)
@@ -338,8 +341,9 @@ impl Expression for ComparisonExpression {
 }
 
 pub struct ContainsExpression {
-    pub collection: Box<dyn Expression>,
-    pub element: Box<dyn Expression>,
+    pub left: Box<dyn Expression>,
+    pub right: Box<dyn Expression>,
+    pub operator: ContainsOperator,
 }
 
 impl Expression for ContainsExpression {
@@ -356,6 +360,26 @@ impl Expression for ContainsExpression {
     }
 }
 
+pub struct OverlapExpression {
+    pub left: Box<dyn Expression>,
+    pub right: Box<dyn Expression>,
+    pub operator: OverlapOperator,
+}
+
+impl Expression for OverlapExpression {
+    fn kind(&self) -> ExpressionKind {
+        ExpressionKind::Overlap
+    }
+
+    fn expr_type(&self, _scope: &Environment) -> DataType {
+        DataType::Boolean
+    }
+
+    fn as_any(&self) -> &dyn Any {
+        self
+    }
+}
+
 pub struct LikeExpression {
     pub input: Box<dyn Expression>,
     pub pattern: Box<dyn Expression>,
