@@ -40,3 +40,15 @@ pub enum BinaryBitwiseOperator {
     RightShift,
     LeftShift,
 }
+
+#[derive(PartialEq)]
+pub enum ContainsOperator {
+    RangeContainsElement,
+    RangeContainsRange,
+}
+
+#[derive(PartialEq)]
+pub enum OverlapOperator {
+    RangeOverlap,
+    ArrayOverlap,
+}
