@@ -1,5 +1,7 @@
+pub mod combinations_generator;
 pub mod dynamic_types;
 pub mod environment;
+pub mod name_generator;
 pub mod object;
 pub mod schema;
 pub mod signature;
