@@ -60,6 +60,22 @@ impl PartialEq for DataType {
             };
         }
 
+        if let DataType::Range(self_type) = self {
+            return if let DataType::Range(other_type) = other {
+                self_type == other_type
+            } else {
+                false
+            };
+        }
+
+        if let DataType::Range(other_type) = other {
+            return if let DataType::Range(self_type) = self {
+                self_type == other_type
+            } else {
+                false
+            };
+        }
+
         if let DataType::Variant(types) = self {
             for data_type in types {
                 if data_type == other {
@@ -249,9 +265,3 @@ impl DataType {
         matches!(self, DataType::Undefined)
     }
 }
-
-/// Function to used with Dynamic Data type
-/// The result is the same type as the first parameter
-pub fn same_type_as_first_parameter(parameters: &[DataType]) -> DataType {
-    parameters[0].clone()
-}
