@@ -33,7 +33,7 @@ const FIXED_LOGICAL_PLAN: [&str; 8] = [
 
 pub enum EvaluationResult {
     Do(Value),
-    SelectedGroups(GitQLObject, Vec<std::string::String>),
+    SelectedGroups(GitQLObject),
     SelectedInfo,
     SetGlobalVariable,
 }
@@ -75,8 +75,10 @@ fn evaluate_select_query(
     let mut alias_table: HashMap<String, String> = query.alias_table;
 
     let hidden_selections_map = query.hidden_selections;
-    let hidden_selections = hidden_selections_map.values().flatten().cloned().collect();
+    let hidden_selections: Vec<String> =
+        hidden_selections_map.values().flatten().cloned().collect();
     let mut statements_map = query.statements;
+    let has_group_by_statement = statements_map.contains_key("group");
 
     for gql_command in FIXED_LOGICAL_PLAN {
         if statements_map.contains_key(gql_command) {
@@ -96,14 +98,12 @@ fn evaluate_select_query(
                         &mut gitql_object,
                         &mut alias_table,
                         &hidden_selections_map,
+                        has_group_by_statement,
                     )?;
 
                     // If the main group is empty, no need to perform other statements
                     if gitql_object.is_empty() || gitql_object.groups[0].is_empty() {
-                        return Ok(EvaluationResult::SelectedGroups(
-                            gitql_object,
-                            hidden_selections,
-                        ));
+                        return Ok(EvaluationResult::SelectedGroups(gitql_object));
                     }
 
                     // Apply the distinct operation object is not empty too.
@@ -121,6 +121,7 @@ fn evaluate_select_query(
                         &mut gitql_object,
                         &mut alias_table,
                         &hidden_selections_map,
+                        has_group_by_statement,
                     )?;
                 }
             }
@@ -128,12 +129,13 @@ fn evaluate_select_query(
     }
 
     // Remove Hidden Selection from the rows after executing the query plan
+    let number_of_groups = gitql_object.groups.len();
     let group: &mut Group = &mut gitql_object.groups[0];
     remove_hidden_selected(&mut gitql_object.titles, group, &hidden_selections);
 
     // If there are many groups that mean group by is executed before.
     // must merge each group into only one element
-    if gitql_object.len() > 1 {
+    if number_of_groups > 1 {
         for group in gitql_object.groups.iter_mut() {
             if group.len() > 1 {
                 group.rows.drain(1..);
@@ -142,14 +144,12 @@ fn evaluate_select_query(
     }
     // If it a single group but it select only aggregations function,
     // should return only first element in the group
-    else if gitql_object.len() == 1
+    else if number_of_groups == 1
         && !query.has_group_by_statement
         && query.has_aggregation_function
+        && group.len() > 1
     {
-        let group: &mut Group = &mut gitql_object.groups[0];
-        if group.len() > 1 {
-            group.rows.drain(1..);
-        }
+        group.rows.drain(1..);
     }
 
     // Into statement must be executed last after flatted and remove hidden selections
@@ -162,16 +162,13 @@ fn evaluate_select_query(
             &mut gitql_object,
             &mut alias_table,
             &hidden_selections_map,
+            has_group_by_statement,
         )?;
 
         return Ok(EvaluationResult::SelectedInfo);
     }
 
-    // Return the groups and hidden selections to be used later in GUI or TUI ...etc
-    Ok(EvaluationResult::SelectedGroups(
-        gitql_object,
-        hidden_selections,
-    ))
+    Ok(EvaluationResult::SelectedGroups(gitql_object))
 }
 
 fn evaluate_global_declaration_query(
@@ -208,12 +205,11 @@ fn evaluate_describe_query(
     }
 
     gitql_object.groups.push(Group { rows });
-    Ok(EvaluationResult::SelectedGroups(gitql_object, vec![]))
+    Ok(EvaluationResult::SelectedGroups(gitql_object))
 }
 
 fn evaluate_show_tables_query(env: &mut Environment) -> Result<EvaluationResult, String> {
     let mut gitql_object = GitQLObject::default();
-    let hidden_selections = vec![];
 
     gitql_object.titles.push("Tables".to_owned());
 
@@ -225,10 +221,7 @@ fn evaluate_show_tables_query(env: &mut Environment) -> Result<EvaluationResult,
         })
     }
 
-    Ok(EvaluationResult::SelectedGroups(
-        gitql_object,
-        hidden_selections,
-    ))
+    Ok(EvaluationResult::SelectedGroups(gitql_object))
 }
 
 fn remove_hidden_selected(
@@ -241,7 +234,7 @@ fn remove_hidden_selected(
         if hidden_selections.contains(&titles[i]) {
             titles.remove(i);
             for row in group.rows.iter_mut() {
-                if row.values.len() < i {
+                if row.values.len() > i {
                     row.values.remove(i);
                 }
             }
