@@ -18,6 +18,7 @@ use gitql_ast::expression::IsNullExpression;
 use gitql_ast::expression::LikeExpression;
 use gitql_ast::expression::LogicalExpression;
 use gitql_ast::expression::NumberExpression;
+use gitql_ast::expression::OverlapExpression;
 use gitql_ast::expression::RegexExpression;
 use gitql_ast::expression::SliceExpression;
 use gitql_ast::expression::StringExpression;
@@ -28,6 +29,8 @@ use gitql_ast::operator::ArithmeticOperator;
 use gitql_ast::operator::BinaryBitwiseOperator;
 use gitql_ast::operator::BinaryLogicalOperator;
 use gitql_ast::operator::ComparisonOperator;
+use gitql_ast::operator::ContainsOperator;
+use gitql_ast::operator::OverlapOperator;
 use gitql_ast::operator::PrefixUnaryOperator;
 use gitql_core::environment::Environment;
 use gitql_core::types::DataType;
@@ -137,6 +140,13 @@ pub fn evaluate_expression(
                 .unwrap();
             evaluate_contains(env, expr, titles, object)
         }
+        Overlap => {
+            let expr = expression
+                .as_any()
+                .downcast_ref::<OverlapExpression>()
+                .unwrap();
+            evaluate_overlap(env, expr, titles, object)
+        }
         Like => {
             let expr = expression
                 .as_any()
@@ -403,7 +413,7 @@ fn evaluate_prefix_unary(
     object: &Vec<Value>,
 ) -> Result<Value, String> {
     let rhs = evaluate_expression(env, &expr.right, titles, object)?;
-    match expr.op {
+    match expr.operator {
         PrefixUnaryOperator::Minus => {
             if rhs.data_type().is_int() {
                 Ok(Value::Integer(-rhs.as_int()))
@@ -493,14 +503,66 @@ fn evaluate_contains(
     titles: &[String],
     object: &Vec<Value>,
 ) -> Result<Value, String> {
-    let collection = evaluate_expression(env, &expr.collection, titles, object)?;
-    let element = evaluate_expression(env, &expr.element, titles, object)?;
+    let lhs = evaluate_expression(env, &expr.left, titles, object)?;
+    let rhs = evaluate_expression(env, &expr.right, titles, object)?;
 
-    let collection_range = collection.as_range();
-    let is_in_range = Ordering::is_ge(collection_range.0.compare(&element))
-        && Ordering::is_le(collection_range.1.compare(&element));
+    match expr.operator {
+        ContainsOperator::RangeContainsElement => {
+            let collection_range = lhs.as_range();
+            let is_in_range = Ordering::is_ge(collection_range.0.compare(&rhs))
+                && Ordering::is_le(collection_range.1.compare(&rhs));
+            Ok(Value::Boolean(is_in_range))
+        }
+        ContainsOperator::RangeContainsRange => {
+            let lhs_range = lhs.as_range();
+            let rhs_range = rhs.as_range();
+            let is_in_range = Ordering::is_ge(lhs_range.0.compare(&rhs_range.0))
+                && Ordering::is_le(lhs_range.1.compare(&rhs_range.1));
+            Ok(Value::Boolean(is_in_range))
+        }
+    }
+}
 
-    Ok(Value::Boolean(is_in_range))
+fn evaluate_overlap(
+    env: &mut Environment,
+    expr: &OverlapExpression,
+    titles: &[String],
+    object: &Vec<Value>,
+) -> Result<Value, String> {
+    let lhs = evaluate_expression(env, &expr.left, titles, object)?;
+    let rhs = evaluate_expression(env, &expr.right, titles, object)?;
+
+    match expr.operator {
+        OverlapOperator::RangeOverlap => {
+            let lhs_range = lhs.as_range();
+            let rhs_range = rhs.as_range();
+            let max_start = if lhs_range.0.compare(&rhs_range.0).is_le() {
+                lhs_range.0
+            } else {
+                rhs_range.0
+            };
+            let max_end = if lhs_range.1.compare(&rhs_range.1).is_gt() {
+                lhs_range.1
+            } else {
+                rhs_range.1
+            };
+            // has_overlap = min(r1.1, r2.1) > max(r1.0, r2.0)
+            let is_overlap = max_end.compare(&max_start).is_le();
+            return Ok(Value::Boolean(is_overlap));
+        }
+        OverlapOperator::ArrayOverlap => {
+            let lhs_array = lhs.as_array();
+            let rhs_array = rhs.as_array();
+            for lhs_element in lhs_array {
+                for rhs_element in rhs_array.iter() {
+                    if lhs_element.equals(rhs_element) {
+                        return Ok(Value::Boolean(true));
+                    }
+                }
+            }
+        }
+    }
+    Ok(Value::Boolean(false))
 }
 
 fn evaluate_like(
