@@ -1,10 +1,6 @@
 use std::cmp;
 use std::cmp::Ordering;
-use std::collections::hash_map::Entry::Vacant;
 use std::collections::HashMap;
-use std::hash::DefaultHasher;
-use std::hash::Hash;
-use std::hash::Hasher;
 use std::io::Write;
 
 use gitql_ast::expression::Expression;
@@ -34,6 +30,7 @@ use gitql_core::value::Value;
 use crate::data_provider::DataProvider;
 use crate::engine_evaluator::evaluate_expression;
 use crate::engine_filter::apply_filter_operation;
+use crate::engine_group::execute_group_by_statement;
 use crate::engine_join::apply_join_operation;
 
 #[allow(clippy::borrowed_box)]
@@ -44,6 +41,7 @@ pub fn execute_statement(
     gitql_object: &mut GitQLObject,
     alias_table: &mut HashMap<String, String>,
     hidden_selection: &HashMap<String, Vec<String>>,
+    has_group_by_statement: bool,
 ) -> Result<(), String> {
     match statement.kind() {
         Do => {
@@ -106,7 +104,13 @@ pub fn execute_statement(
                 .as_any()
                 .downcast_ref::<AggregationsStatement>()
                 .unwrap();
-            execute_aggregation_function_statement(env, statement, gitql_object, alias_table)
+            execute_aggregation_function_statement(
+                env,
+                statement,
+                gitql_object,
+                alias_table,
+                has_group_by_statement,
+            )
         }
         Into => {
             let statement = statement.as_any().downcast_ref::<IntoStatement>().unwrap();
@@ -411,62 +415,12 @@ fn execute_order_by_statement(
     Ok(())
 }
 
-fn execute_group_by_statement(
-    env: &mut Environment,
-    statement: &GroupByStatement,
-    gitql_object: &mut GitQLObject,
-) -> Result<(), String> {
-    if gitql_object.is_empty() {
-        return Ok(());
-    }
-
-    let main_group: Group = gitql_object.groups.remove(0);
-    if main_group.is_empty() {
-        return Ok(());
-    }
-
-    // Mapping each unique value to it group index
-    let mut groups_map: HashMap<u64, usize> = HashMap::new();
-
-    // Track current group index
-    let mut next_group_index = 0;
-    let values_count = statement.values.len();
-
-    for object in main_group.rows.into_iter() {
-        let mut row_values: Vec<String> = Vec::with_capacity(values_count);
-
-        for expression in &statement.values {
-            let value = evaluate_expression(env, expression, &gitql_object.titles, &object.values)?;
-            row_values.push(value.to_string());
-        }
-
-        // Compute the hash for row of values
-        let mut hasher = DefaultHasher::new();
-        row_values.hash(&mut hasher);
-        let values_hash = hasher.finish();
-
-        // Push a new group for this unique value and update the next index
-        if let Vacant(e) = groups_map.entry(values_hash) {
-            e.insert(next_group_index);
-            next_group_index += 1;
-            gitql_object.groups.push(Group { rows: vec![object] });
-        }
-        // If there is an existing group for this value, append current object to it
-        else {
-            let index = *groups_map.get(&values_hash).unwrap();
-            let target_group = &mut gitql_object.groups[index];
-            target_group.rows.push(object);
-        }
-    }
-
-    Ok(())
-}
-
 fn execute_aggregation_function_statement(
     env: &mut Environment,
     statement: &AggregationsStatement,
     gitql_object: &mut GitQLObject,
     alias_table: &HashMap<String, String>,
+    is_query_has_group_by: bool,
 ) -> Result<(), String> {
     // Make sure you have at least one aggregation function to calculate
     let aggregations_map = &statement.aggregations;
@@ -474,9 +428,6 @@ fn execute_aggregation_function_statement(
         return Ok(());
     }
 
-    // Used to determine if group by statement is executed before or not
-    let groups_count = gitql_object.len();
-
     // We should run aggregation function for each group
     for group in &mut gitql_object.groups {
         // No need to apply all aggregation if there is no selected elements
@@ -559,7 +510,7 @@ fn execute_aggregation_function_statement(
 
         // In case of group by statement is executed
         // Remove all elements expect the first one
-        if groups_count > 1 {
+        if is_query_has_group_by {
             group.rows.drain(1..);
         }
     }
