@@ -11,6 +11,7 @@ pub enum TokenKind {
     Limit,
     Offset,
     Order,
+    Using,
     By,
     In,
     Is,
@@ -59,13 +60,16 @@ pub enum TokenKind {
 
     As,
 
+    With,
+    Rollup,
+
     LeftParen,
     RightParen,
     LeftBracket,
     RightBracket,
 
-    LogicalOr,
-    LogicalAnd,
+    OrOr,
+    AndAnd,
     LogicalXor,
 
     BitwiseNot,
@@ -398,7 +402,7 @@ pub fn tokenize(script: String) -> Result<Vec<Token>, Box<Diagnostic>> {
             let mut kind = TokenKind::BitwiseOr;
             let literal = if position < len && characters[position] == '|' {
                 position += 1;
-                kind = TokenKind::LogicalOr;
+                kind = TokenKind::OrOr;
                 "||"
             } else {
                 "|"
@@ -425,7 +429,7 @@ pub fn tokenize(script: String) -> Result<Vec<Token>, Box<Diagnostic>> {
             let mut kind = TokenKind::BitwiseAnd;
             let literal = if position < len && characters[position] == '&' {
                 position += 1;
-                kind = TokenKind::LogicalAnd;
+                kind = TokenKind::AndAnd;
                 "&&"
             } else {
                 "&"
@@ -1134,13 +1138,11 @@ fn resolve_symbol_kind(literal: String) -> TokenKind {
         "select" => TokenKind::Select,
         "distinct" => TokenKind::Distinct,
         "from" => TokenKind::From,
-        "group" => TokenKind::Group,
         "where" => TokenKind::Where,
-        "having" => TokenKind::Having,
         "limit" => TokenKind::Limit,
         "offset" => TokenKind::Offset,
         "order" => TokenKind::Order,
-        "by" => TokenKind::By,
+        "using" => TokenKind::Using,
         "case" => TokenKind::Case,
         "when" => TokenKind::When,
         "then" => TokenKind::Then,
@@ -1157,14 +1159,6 @@ fn resolve_symbol_kind(literal: String) -> TokenKind {
         "show" => TokenKind::Show,
         "regexp" => TokenKind::RegExp,
 
-        // Joins
-        "join" => TokenKind::Join,
-        "left" => TokenKind::Left,
-        "right" => TokenKind::Right,
-        "cross" => TokenKind::Cross,
-        "inner" => TokenKind::Inner,
-        "outer" => TokenKind::Outer,
-
         // Select into
         "into" => TokenKind::Into,
         "outfile" => TokenKind::Outfile,
@@ -1174,13 +1168,28 @@ fn resolve_symbol_kind(literal: String) -> TokenKind {
         "enclosed" => TokenKind::Enclosed,
         "terminated" => TokenKind::Terminated,
 
+        // Joins
+        "join" => TokenKind::Join,
+        "left" => TokenKind::Left,
+        "right" => TokenKind::Right,
+        "cross" => TokenKind::Cross,
+        "inner" => TokenKind::Inner,
+        "outer" => TokenKind::Outer,
+
+        // Grouping
+        "group" => TokenKind::Group,
+        "by" => TokenKind::By,
+        "having" => TokenKind::Having,
+        "with" => TokenKind::With,
+        "rollup" => TokenKind::Rollup,
+
         // Integer division and Modulo operator
         "div" => TokenKind::Slash,
         "mod" => TokenKind::Percentage,
 
         // Logical Operators
-        "or" => TokenKind::LogicalOr,
-        "and" => TokenKind::LogicalAnd,
+        "or" => TokenKind::OrOr,
+        "and" => TokenKind::AndAnd,
         "xor" => TokenKind::LogicalXor,
 
         // True, False and Null
@@ -1194,13 +1203,13 @@ fn resolve_symbol_kind(literal: String) -> TokenKind {
         // As for alias
         "as" => TokenKind::As,
 
-        // Array data type
-        "array" => TokenKind::Array,
-
         // Order by DES and ASC
         "asc" => TokenKind::Ascending,
         "desc" => TokenKind::Descending,
 
+        // Array data type
+        "array" => TokenKind::Array,
+
         // Identifier
         _ => TokenKind::Symbol,
     }
