@@ -2,9 +2,10 @@ use std::cmp::Ordering;
 use std::collections::HashMap;
 use std::sync::OnceLock;
 
+use gitql_core::dynamic_types::array_of_type;
+use gitql_core::dynamic_types::first_element_type;
 use gitql_core::signature::Aggregation;
 use gitql_core::signature::Signature;
-use gitql_core::types::same_type_as_first_parameter;
 use gitql_core::types::DataType;
 use gitql_core::value::Value;
 
@@ -22,6 +23,8 @@ pub fn aggregation_functions() -> &'static HashMap<&'static str, Aggregation> {
         map.insert("bool_or", aggregation_bool_or);
         map.insert("bit_and", aggregation_bit_and);
         map.insert("bit_or", aggregation_bit_or);
+        map.insert("bit_xor", aggregation_bit_xor);
+        map.insert("array_agg", aggregation_array_agg);
         map
     })
 }
@@ -41,7 +44,7 @@ pub fn aggregation_function_signatures() -> &'static HashMap<&'static str, Signa
                     DataType::Time,
                     DataType::DateTime,
                 ])],
-                return_type: DataType::Dynamic(same_type_as_first_parameter),
+                return_type: DataType::Dynamic(first_element_type),
             },
         );
         map.insert(
@@ -55,7 +58,7 @@ pub fn aggregation_function_signatures() -> &'static HashMap<&'static str, Signa
                     DataType::Time,
                     DataType::DateTime,
                 ])],
-                return_type: DataType::Dynamic(same_type_as_first_parameter),
+                return_type: DataType::Dynamic(first_element_type),
             },
         );
         map.insert(
@@ -114,6 +117,22 @@ pub fn aggregation_function_signatures() -> &'static HashMap<&'static str, Signa
                 return_type: DataType::Integer,
             },
         );
+        map.insert(
+            "bit_xor",
+            Signature {
+                parameters: vec![DataType::Integer],
+                return_type: DataType::Integer,
+            },
+        );
+        map.insert(
+            "array_agg",
+            Signature {
+                parameters: vec![DataType::Any],
+                return_type: DataType::Dynamic(|elements| {
+                    array_of_type(first_element_type(elements))
+                }),
+            },
+        );
         map
     })
 }
@@ -224,3 +243,36 @@ pub fn aggregation_bit_or(group_values: Vec<Vec<Value>>) -> Value {
         Value::Null
     }
 }
+
+pub fn aggregation_bit_xor(group_values: Vec<Vec<Value>>) -> Value {
+    let mut value: i64 = 0;
+    let mut has_non_null = false;
+    for row_values in group_values {
+        if row_values[0].data_type().is_null() {
+            continue;
+        }
+        value ^= row_values[0].as_int();
+        has_non_null = true;
+    }
+
+    if has_non_null {
+        Value::Integer(value)
+    } else {
+        Value::Null
+    }
+}
+
+pub fn aggregation_array_agg(group_values: Vec<Vec<Value>>) -> Value {
+    let mut array: Vec<Value> = vec![];
+    for row_values in group_values {
+        array.push(row_values[0].clone());
+    }
+
+    let element_type = if array.is_empty() {
+        DataType::Null
+    } else {
+        array[0].data_type()
+    };
+
+    Value::Array(element_type, array)
+}
