@@ -20,8 +20,10 @@ pub fn register_std_array_functions(map: &mut HashMap<&'static str, Function>) {
     map.insert("array_length", array_length);
     map.insert("array_shuffle", array_shuffle);
     map.insert("array_position", array_position);
+    map.insert("array_positions", array_positions);
     map.insert("array_dims", array_dims);
     map.insert("array_replace", array_replace);
+    map.insert("trim_array", array_trim);
 }
 
 #[inline(always)]
@@ -108,6 +110,13 @@ pub fn register_std_array_function_signatures(map: &mut HashMap<&'static str, Si
             return_type: DataType::Dynamic(first_element_type),
         },
     );
+    map.insert(
+        "trim_array",
+        Signature {
+            parameters: vec![DataType::Array(Box::new(DataType::Any)), DataType::Integer],
+            return_type: DataType::Dynamic(first_element_type),
+        },
+    );
 }
 
 pub fn array_append(inputs: &[Value]) -> Value {
@@ -168,6 +177,18 @@ pub fn array_position(inputs: &[Value]) -> Value {
     Value::Null
 }
 
+pub fn array_positions(inputs: &[Value]) -> Value {
+    let array = inputs[0].as_array();
+    let target = &inputs[1];
+    let mut positions: Vec<Value> = vec![];
+    for (index, element) in array.into_iter().enumerate() {
+        if element.equals(target) {
+            positions.push(Value::Integer((index + 1) as i64));
+        }
+    }
+    Value::Array(DataType::Array(Box::new(DataType::Integer)), positions)
+}
+
 pub fn array_dims(inputs: &[Value]) -> Value {
     let array_type = inputs[0].data_type();
     Value::Text(array_type.to_string())
@@ -185,3 +206,12 @@ pub fn array_replace(inputs: &[Value]) -> Value {
     }
     Value::Array(array_type, array_values)
 }
+
+pub fn array_trim(inputs: &[Value]) -> Value {
+    let mut array = inputs[0].as_array();
+    let array_type = inputs[0].data_type();
+    let array_len = array.len();
+    let n = i64::min(array.len().try_into().unwrap(), inputs[1].as_int());
+    array.truncate(array_len - n as usize);
+    Value::Array(array_type, array)
+}
